Documentation
¶
Overview ¶
Package e2e provides methods to test CAPH provider integration e2e.
Index ¶
- Constants
- func Byf(format string, a ...interface{})
- func CaphClusterDeploymentSpec(ctx context.Context, inputGetter func() CaphClusterDeploymentSpecInput)
- func ClusterctlUpgradeSpec(ctx context.Context, inputGetter func() ClusterctlUpgradeSpecInput)
- func HaveValidVersion(version string) types.GomegaMatcher
- type CaphClusterDeploymentSpecInput
- type ClusterctlUpgradeSpecInput
Constants ¶
const ( RedactLogScriptPath = "REDACT_LOG_SCRIPT" KubernetesVersion = "KUBERNETES_VERSION" CiliumPath = "CILIUM" CiliumResources = "CILIUM_RESOURCES" CCMPath = "CCM" CCMResources = "CCM_RESOURCES" CCMNetworkPath = "CCM_NETWORK" CCMNetworkResources = "CCM_RESOURCES_NETWORK" CCMHetznerPath = "CCM_HETZNER" CCMHetznerResources = "CCM_RESOURCES_HETZNER" )
Test suite constants for e2e config variables.
Variables ¶
This section is empty.
Functions ¶
func CaphClusterDeploymentSpec ¶
func CaphClusterDeploymentSpec(ctx context.Context, inputGetter func() CaphClusterDeploymentSpecInput)
CaphClusterDeploymentSpec implements a test that verifies that MachineDeployment rolling updates are successful.
func ClusterctlUpgradeSpec ¶
func ClusterctlUpgradeSpec(ctx context.Context, inputGetter func() ClusterctlUpgradeSpecInput)
ClusterctlUpgradeSpec implements a test that verifies clusterctl upgrade of a management cluster. It tests an older infrastructure provider against a newer one.
func HaveValidVersion ¶
func HaveValidVersion(version string) types.GomegaMatcher
HaveValidVersion succeeds if version is a valid semver version.
Types ¶
type CaphClusterDeploymentSpecInput ¶
type CaphClusterDeploymentSpecInput struct {
E2EConfig *clusterctl.E2EConfig
ClusterctlConfigPath string
BootstrapClusterProxy framework.ClusterProxy
ArtifactFolder string
SkipCleanup bool
Flavor string
WorkerMachineCount int64
ControlPlaneMachineCount int64
}
CaphClusterDeploymentSpecInput is the input for CaphClusterDeploymentSpec.
type ClusterctlUpgradeSpecInput ¶
type ClusterctlUpgradeSpecInput struct {
E2EConfig *clusterctl.E2EConfig
ClusterctlConfigPath string
BootstrapClusterProxy framework.ClusterProxy
ArtifactFolder string
// InitWithBinary can be used to override the INIT_WITH_BINARY e2e config variable with the URL of the clusterctl binary of the old version of Cluster API. The spec will interpolate the
// strings `{OS}` and `{ARCH}` to `runtime.GOOS` and `runtime.GOARCH` respectively, e.g. https://github.com/kubernetes-sigs/cluster-api/releases/download/v0.3.23/clusterctl-{OS}-{ARCH}
InitWithBinary string
// InitWithInfrastructureProviderVersion can be used to define the initialised version of the infrastructure provider.
InitWithInfrastructureProviderVersion string
// InitWithProvidersContract can be used to override the INIT_WITH_PROVIDERS_CONTRACT e2e config variable with a specific
// provider contract to use to initialise the secondary management cluster, e.g. `v1alpha3`
InitWithProvidersContract string
SkipCleanup bool
PreInit func(managementClusterProxy framework.ClusterProxy)
PreUpgrade func(managementClusterProxy framework.ClusterProxy)
PostUpgrade func(managementClusterProxy framework.ClusterProxy)
MgmtFlavor string
WorkloadFlavor string
}
ClusterctlUpgradeSpecInput is the input for ClusterctlUpgradeSpec.
Click to show internal directories.
Click to hide internal directories.